<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\COZ\Services\RequisicaoPlanejamentoProducaoService;

class RequisicaoPlanejamentoProducaoController extends \Teknisa\GER\Controllers\TeknisaCrud {

	const servico_por_multi_filial = 'servico_por_multi_filial';
    const filial_agregada = 'filial_agregada';

    protected $crudService;
    protected $dataSourceManager;
    protected $environment;
    protected $requisicaoPlanejamentoProducaoService;
    protected $dataSourceName = "requisicaoplanejamentoproducao";
    protected $parameterBagColumns = array(
    	"NRORG"
	);

	 public function __construct(
         \Teknisa\GER\Services\CrudService $crudService, $parameterBag, $dataSourceManager,
         $environment, $requisicaoPlanejamentoProducaoService) {
        $this->requisicaoPlanejamentoProducaoService = $requisicaoPlanejamentoProducaoService;
        $this->dataSourceManager = $dataSourceManager;
        $this->environment        = $environment;
    	parent::__construct($crudService, $parameterBag);
    }

    public function retornaServicoPorFilial(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria();
            $conditions = $filter->getConditions();
            $nrorg = $this->environment->getNrOrg();
            $cdfilial = isset($conditions[1]['value']) ? $conditions[1]['value'] : null;

            $filterCriteria = new FilterCriteria(self::servico_por_multi_filial);
			$this->parameterBagColumns = array('CDFILIAL');
			$filterCriteria->addCondition('CDFILIAL', $cdfilial);
			$filterCriteria->setDataSourceName(self::servico_por_multi_filial);
			$newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
	    	$dataSet = $this->dataSourceManager->findBy($newFilterCriteria);

            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

    public function retornaFilialAgregada(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $filter = $request->getFilterCriteria();
            $conditions = $filter->getConditions();
            $nrorg = $conditions[0]['value'];
            $cdcentral = $conditions[1]['value'];

            $filterCriteria = new FilterCriteria(self::filial_agregada);
            $this->parameterBagColumns = array('CDCENTRAL');
            $filterCriteria->addCondition('CDCENTRAL', $cdcentral);
            $filterCriteria->setDataSourceName(self::filial_agregada);
            $newFilterCriteria = $this->crudService->populateParameterBag($filterCriteria, $this->parameterBagColumns);
            $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);

            $response->addDataSet($dataSet);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }
}