<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\COZ\Services\Coz07200DistribuicaoDaRefeicaoService;

class Utilities extends \Teknisa\GER\Controllers\TeknisaCrud {

    protected $environment;
    protected $dataSourceManager;
    protected $crudService; 
    protected $parameterBag;
    protected $entityManager;
    protected $lista;


    public function __construct($crudService, $parameterBag, $dataSourceManager, $environment,$entityManager, $lista) {
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        parent::__construct($crudService, $parameterBag);
        $this->entityManager    = $entityManager;
        $this->lista = $lista;
    }

    public function retornaCentralDefault(DTO\Request\Row $request, DTO\Response $response) {
        try{
            $filterCriteria = new FilterCriteria('filial');
            $filterCriteria->addCondition('CDFILIAL', $this->environment->getCdFilial());
            $filterCriteria->addCondition('IDTPFILIALCENT', 'C');
    
            $dataSetLogged = $this->dataSourceManager->findBy($filterCriteria);
            $rowsLogged = $dataSetLogged->getRows();
         
            if (count($rowsLogged) > 0) {
                $rows = $rowsLogged[0];
            } else {
                $filterCriteria = new FilterCriteria('filial');
                $filterCriteria->addCondition('CDFILIAL', $this->environment->getCdFilial());
    
                $dataSet = $this->dataSourceManager->findBy($filterCriteria);
                $rows = $dataSet->getRows();
                
                if($rows[0]['CDFILCENTPME'] !== null) {
                    $filterCriteria = new FilterCriteria('filial');
                    $filterCriteria->addCondition('CDFILIAL', $rows[0]['CDFILCENTPME']);
                    $filterCriteria->addCondition('IDTPFILIALCENT', 'C');
        
                    $dataSet = $this->dataSourceManager->findBy($filterCriteria);
                    $rows = $dataSet->getRows();
                    if (count($rows) > 0) {
                        $rows = $dataSet->getRows()[0];    
                    } else {
                        $rows = array();
                    }
                } else {
                    $rows = array();
                }
            }
             $response->addDataSet(new DataSet('central', $rows));   
        } catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    
    public function verificaQtdeConsumida(DTO\Request\Row $request, DTO\Response $response){
        try{
            $row = $request->getRow();
            $message = "";
            $nrlista = $this->lista->geraLista($row['LISTA_PRODUTO'], $this->environment->getNrOrgTrab());
            $params = array(
                "NRLISTA" => $nrlista, 
                "NRPLANPROD" => $row['NRPLANPROD']
            );
            $query = "SELECT R.CDPRODUTO, SUM(R.QTPRODRECEPRAT) AS QTPRODRECEPRAT, SUM(R.QTAPRODUZIR) AS QTAPRODUZIR, SUM(R.QTEXTRA) AS QTEXTRA, SUM(R.QTDEVOLVIDA) AS QTDEVOLVIDA, SUM(R.QTLIBERADA) AS QTLIBERADA, R.NRPLANPROD FROM PLANRECPROD R INNER JOIN LISTA L ON L.CDLISTA = R.CDPRODACABADO AND L.NRLISTA = :NRLISTA WHERE R.NRPLANPROD = :NRPLANPROD GROUP BY R.CDPRODUTO, R.NRPLANPROD";
            $data = $this->entityManager->getConnection()->fetchAll($query, $params);
            
            foreach($data as $value){
                if($value['QTAPRODUZIR'] <= 0 and $value['QTLIBERADA'] > 0){
                    if($value['QTDEVOLVIDA'] <= 0 || $value['QTDEVOLVIDA'] == null){
                        $message = "Operação bloqueada! A quantidade consumida dos insumos não foi informada.";
                    }    
                }
            }
            
            $response->addDataSet(new DataSet('msgQtdeConsumida', array($message)));   
        }catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

}